/*
 * Copyright Redis Ltd. 2016 - present
 * Licensed under your choice of the Redis Source Available License 2.0 (RSALv2) or
 * the Server Side Public License v1 (SSPLv1).
 */

#ifndef _CRC12_TABLE_H__
#define _CRC12_TABLE_H__

/* A table of the shortest possible alphanumeric string that is mapped by redis' crc12
 * to any given redis cluster slot.
 *
 * The array indexes are slot numbers, so that given a desired slot, this string is guaranteed
 * to make redis cluster route a request to the shard holding this slot
 */

static const char *crc12_slot_table[] = {
    "pg5", "phC", "pb7", "0",   "paI", "P",   "pai", "p",   "pyy", "pp3", "pyY", "pu1", "ppc",
    "pps", "ppC", "ppS", "pEa", "pCM", "pEA", "pCm", "pIY", "pE1", "pIy", "pIi", "5B",  "0p",
    "5b",  "0P",  "9z",  "00",  "9Z",  "52",  "Yz",  "P0",  "YZ",  "U2",  "UB",  "Pp",  "Ub",
    "PP",  "G6",  "D8",  "B4",  "MB",  "AJ",  "AZ",  "Aj",  "Az",  "qj",  "qz",  "qJ",  "qZ",
    "r4",  "t0c", "w6",  "t8",  "eb",  "cN",  "eB",  "cn",  "iZ",  "e2",  "iz",  "ij",  "0Ec",
    "0CO", "0EC", "0Co", "0JE", "0E3", "0Je", "0Ik", "0Qk", "0Re", "0QK", "0RE", "0R5", "0Xa",
    "0W7", "0T9", "0g7", "0d9", "0b5", "0ha", "0aK", "0bE", "0ak", "0be", "0ze", "0p1", "0zE",
    "0u3", "0pa", "0pq", "0pA", "0pQ", "401", "51o", "453", "51O", "40q", "40a", "40Q", "40A",
    "613", "68y", "641", "68Y", "61s", "61c", "61S", "61C", "025", "08a", "077", "049", "01k",
    "02e", "01K", "02E", "237", "209", "265", "29C", "20i", "20y", "20I", "20Y", "R5",  "Xa",
    "W7",  "T9",  "Qk",  "Re",  "QK",  "RE",  "JE",  "E3",  "Je",  "Ik",  "Ec",  "CO",  "EC",
    "Co",  "pa",  "pq",  "pA",  "pQ",  "ze",  "p1",  "zE",  "u3",  "aK",  "bE",  "ak",  "be",
    "g7",  "d9",  "b5",  "ha",  "piX", "pe0", "pix", "pih", "qg0", "pcL", "pi8", "pcl", "pr6",
    "pq8", "pw4", "pxB", "pqh", "pqx", "pqH", "pqX", "pAH", "pAX", "pAh", "pAx", "pG4", "pHB",
    "pB6", "pA8", "1k",  "2e",  "1K",  "2E",  "25",  "8a",  "77",  "49",  "50t", "424", "448",
    "476", "41z", "41j", "41Z", "41J", "608", "636", "69B", "664", "60x", "60h", "60X", "60H",
    "09z", "000", "09Z", "052", "05B", "00p", "05b", "00P", "28x", "212", "28X", "240", "21b",
    "21r", "21B", "21R", "0AJ", "0AZ", "0Aj", "0Az", "0G6", "0D8", "0B4", "0MB", "0UB", "0Pp",
    "0Ub", "0PP", "0Yz", "0P0", "0YZ", "0U2", "0iZ", "0e2", "0iz", "0ij", "0eb", "0cN", "0eB",
    "0cn", "0r4", "1pt", "0w6", "0t8", "0qj", "0qz", "0qJ", "0qZ", "0AI", "0AY", "0Ai", "0Ay",
    "0G5", "0HC", "0B7", "0A9", "0Pc", "0Ps", "0PC", "0PS", "0Yy", "0P3", "0YY", "0U1", "0iY",
    "0e1", "0iy", "0ii", "0ea", "0cM", "0eA", "0cm", "0r7", "0q9", "0w5", "0xC", "0qi", "0qy",
    "0qI", "0qY", "419", "427", "48C", "475", "41y", "41i", "41Y", "41I", "69a", "635", "659",
    "667", "63e", "60k", "63E", "60K", "09y", "003", "09Y", "051", "00c", "00s", "00C", "00S",
    "30o", "211", "30O", "243", "21a", "21q", "21A", "21Q", "pjE", "pe3", "pje", "pik", "pec",
    "pcO", "peC", "pco", "pr5", "pxa", "pw7", "pt9", "pqk", "pre", "pqK", "prE", "pAK", "pBE",
    "pAk", "pBe", "pG7", "pD9", "pB5", "pHa", "1h",  "1x",  "1H",  "1X",  "26",  "18",  "74",
    "8B",  "R6",  "Q8",  "W4",  "XB",  "Qh",  "Qx",  "QH",  "QX",  "IX",  "E0",  "Ix",  "Ih",
    "r1c", "CL",  "I8",  "Cl",  "pb",  "pr",  "pB",  "pR",  "yx",  "p2",  "yX",  "u0",  "aH",
    "aX",  "ah",  "ax",  "g4",  "hB",  "b6",  "a8",  "402", "49x", "450", "49X", "40r", "40b",
    "40R", "40B", "610", "68z", "642", "68Z", "61p", "64B", "61P", "64b", "026", "018", "074",
    "08B", "01h", "01x", "01H", "01X", "234", "31t", "266", "258", "20j", "20z", "20J", "20Z",
    "1G0", "0CL", "0I8", "0Cl", "0IX", "0E0", "0Ix", "0Ih", "0Qh", "0Qx", "0QH", "0QX", "0R6",
    "0Q8", "0W4", "0XB", "0g4", "0hB", "0b6", "0a8", "0aH", "0aX", "0ah", "0ax", "0yx", "0p2",
    "0yX", "0u0", "0pb", "0pr", "0pB", "0pR", "Yy",  "P3",  "YY",  "U1",  "Pc",  "Ps",  "PC",
    "PS",  "G5",  "HC",  "B7",  "A9",  "AI",  "AY",  "Ai",  "Ay",  "qi",  "qy",  "qI",  "qY",
    "r7",  "q9",  "w5",  "xC",  "ea",  "cM",  "eA",  "cm",  "iY",  "e1",  "iy",  "ii",  "pg6",
    "pd8", "pb4", "3",   "C",   "S",   "c",   "s",   "pyz", "pp0", "pyZ", "pu2", "puB", "ppp",
    "pub", "ppP", "pEb", "pCN", "pEB", "pCn", "pIZ", "pE2", "pIz", "pIj", "0c",  "0s",  "0C",
    "0S",  "9y",  "03",  "9Y",  "51",  "Za",  "P5",  "V9",  "U7",  "Pe",  "Pu",  "PE",  "PU",
    "G3",  "HE",  "B1",  "He",  "AO",  "BA",  "Ao",  "Ba",  "qo",  "ra",  "qO",  "rA",  "r1",
    "xe",  "w3",  "xE",  "eg",  "cK",  "eG",  "ck",  "f9",  "e7",  "ja",  "io",  "pg0", "phF",
    "pb2", "5",   "E",   "U",   "e",   "u",   "ps8", "pp6", "pzB", "pu4", "ppf", "ppv", "ppF",
    "ppV", "pCX", "pCH", "pCx", "pCh", "pJB", "pE4", "pC8", "pIl", "0e",  "0u",  "0E",  "0U",
    "pR2", "05",  "69",  "57",  "404", "51j", "456", "468", "40t", "40d", "40T", "40D", "616",
    "628", "644", "70H", "61v", "61f", "61V", "61F", "020", "08d", "072", "08D", "01n", "07B",
    "01N", "07b", "232", "29f", "260", "29F", "20l", "23b", "20L", "23B", "0CZ", "0CJ", "0Cz",
    "0Cj", "0F8", "0E6", "0OB", "0In", "0Qn", "0WB", "0QN", "0Wb", "0R0", "0Xd", "0W2", "0XD",
    "0g2", "0hD", "0b0", "0hd", "0aN", "0gb", "0an", "0gB", "1qj", "0p4", "0v8", "0u6", "0pd",
    "0pt", "0pD", "0pT", "pjC", "pe5", "pc9", "pim", "pcY", "pcI", "pcy", "pci", "pr3", "pxg",
    "pw1", "pxG", "pqm", "prc", "pqM", "prC", "pAM", "pBC", "pAm", "pBc", "pG1", "pHG", "pB3",
    "pHg", "1n",  "7B",  "1N",  "7b",  "20",  "8d",  "72",  "8D",  "R0",  "Xd",  "W2",  "XD",
    "Qn",  "WB",  "QN",  "Wb",  "F8",  "E6",  "OB",  "In",  "CZ",  "CJ",  "Cz",  "Cj",  "pd",
    "pt",  "pD",  "pT",  "t2c", "p4",  "v8",  "u6",  "aN",  "gb",  "an",  "gB",  "g2",  "hD",
    "b0",  "hd",  "0AO", "0BA", "0Ao", "0Ba", "0G3", "0HE", "0B1", "0He", "0Pe", "0Pu", "0PE",
    "0PU", "0Za", "0P5", "0V9", "0U7", "0f9", "0e7", "0ja", "0io", "0eg", "0cK", "0eG", "0ck",
    "0r1", "0xe", "0w3", "0xE", "0qo", "0ra", "0qO", "0rA", "48e", "421", "48E", "473", "42a",
    "41o", "42A", "41O", "69g", "633", "69G", "661", "63c", "60m", "63C", "60M", "11k", "005",
    "069", "057", "00e", "00u", "00E", "00U", "229", "217", "30I", "245", "21g", "21w", "21G",
    "21W", "48f", "422", "48F", "470", "42b", "41l", "42B", "41L", "69d", "630", "69D", "662",
    "66B", "60n", "66b", "60N", "038", "006", "11H", "054", "00f", "00v", "00F", "00V", "30j",
    "214", "278", "246", "21d", "21t", "21D", "21T", "0AL", "0BB", "0Al", "0Bb", "0G0", "0HF",
    "0B2", "0Hf", "0Pf", "0Pv", "0PF", "0PV", "0S8", "0P6", "0ZB", "0U4", "0jB", "0e4", "0c8",
    "0il", "0cX", "0cH", "0cx", "0ch", "0r2", "0xf", "0w0", "0xF", "0ql", "0rb", "0qL", "0rB",
    "R3",  "Xg",  "W1",  "XG",  "Qm",  "Rc",  "QM",  "RC",  "JC",  "E5",  "C9",  "Im",  "CY",
    "CI",  "Cy",  "Ci",  "pg",  "pw",  "pG",  "pW",  "s9",  "p7",  "zC",  "u5",  "aM",  "bC",
    "am",  "bc",  "g1",  "hG",  "b3",  "hg",  "pf8", "pe6", "poB", "pin", "pcZ", "pcJ", "pcz",
    "pcj", "pr0", "pxd", "pw2", "pxD", "pqn", "pwB", "pqN", "pwb", "pAN", "pGb", "pAn", "pGB",
    "pG2", "pHD", "pB0", "pHd", "1m",  "2c",  "1M",  "2C",  "23",  "8g",  "71",  "8G",  "0CY",
    "0CI", "0Cy", "0Ci", "0JC", "0E5", "0C9", "0Im", "0Qm", "0Rc", "0QM", "0RC", "0R3", "0Xg",
    "0W1", "0XG", "0g1", "0hG", "0b3", "0hg", "0aM", "0bC", "0am", "0bc", "0s9", "0p7", "0zC",
    "0u5", "0pg", "0pw", "0pG", "0pW", "407", "439", "455", "51I", "40w", "40g", "40W", "40G",
    "615", "70k", "647", "679", "61u", "61e", "61U", "61E", "023", "08g", "071", "08G", "01m",
    "02c", "01M", "02C", "231", "29e", "263", "29E", "20o", "23a", "20O", "23A", "pg3", "phE",
    "pb1", "6",   "F",   "V",   "f",   "v",   "pza", "pp5", "pv9", "pu7", "ppe", "ppu", "ppE",
    "ppU", "pEg", "pCK", "pEG", "pCk", "pF9", "pE7", "pJa", "pIo", "0f",  "0v",  "0F",  "0V",
    "38",  "06",  "pW3", "54",  "S8",  "P6",  "ZB",  "U4",  "Pf",  "Pv",  "PF",  "PV",  "G0",
    "HF",  "B2",  "Hf",  "AL",  "BB",  "Al",  "Bb",  "ql",  "rb",  "qL",  "rB",  "r2",  "xf",
    "w0",  "xF",  "cX",  "cH",  "cx",  "ch",  "jB",  "e4",  "c8",  "il",  "0CU", "0CE", "0Cu",
    "0Ce", "0F7", "0E9", "0C5", "0Ia", "0Qa", "0Qq", "0QA", "0QQ", "1Po", "0Q1", "1PO", "0T3",
    "0kE", "0d3", "0ke", "0a1", "0aA", "0aQ", "0aa", "0aq", "0s5", "0ya", "0v7", "0u9", "0pk",
    "0se", "0pK", "0sE", "49a", "435", "459", "467", "43e", "40k", "43E", "40K", "619", "627",
    "68C", "675", "61y", "61i", "61Y", "61I", "10o", "011", "10O", "043", "01a", "01q", "01A",
    "01Q", "29y", "203", "29Y", "251", "20c", "20s", "20C", "20S", "phY", "pd1", "phy", "pa3",
    "J",   "Z",   "j",   "z",   "ps7", "pp9", "pv5", "pyC", "ppi", "ppy", "ppI", "ppY", "pCW",
    "pCG", "pCw", "pCg", "pF5", "pIC", "pC7", "pIc", "0j",  "0z",  "0J",  "0Z",  "34",  "pQ3",
    "66",  "58",  "S4",  "p13", "V6",  "U8",  "Pj",  "Pz",  "PJ",  "PZ",  "HZ",  "D2",  "Hz",
    "A0",  "Db",  "AP",  "DB",  "Ap",  "tB",  "qp",  "tb",  "qP",  "xz",  "q0",  "xZ",  "t2",
    "cT",  "cD",  "ct",  "cd",  "f6",  "e8",  "c4",  "lB",  "410", "48z", "442", "48Z", "41p",
    "44B", "41P", "44b", "602", "69x", "650", "69X", "60r", "60b", "60R", "60B", "034", "11t",
    "066", "058", "00j", "00z", "00J", "00Z", "226", "218", "274", "28B", "21h", "21x", "21H",
    "21X", "0Db", "0AP", "0DB", "0Ap", "0HZ", "0D2", "0Hz", "0A0", "0Pj", "0Pz", "0PJ", "0PZ",
    "0S4", "1Qt", "0V6", "0U8", "0f6", "0e8", "0c4", "0lB", "0cT", "0cD", "0ct", "0cd", "0xz",
    "0q0", "0xZ", "0t2", "0tB", "0qp", "0tb", "0qP", "p36", "Q1",  "p64", "T3",  "Qa",  "Qq",
    "QA",  "QQ",  "F7",  "E9",  "C5",  "Ia",  "CU",  "CE",  "Cu",  "Ce",  "pk",  "se",  "pK",
    "sE",  "s5",  "ya",  "v7",  "u9",  "aA",  "aQ",  "aa",  "aq",  "kE",  "d3",  "ke",  "a1",
    "pf4", "piB", "pc6", "pib", "pcV", "pcF", "pcv", "pcf", "pxx", "pq2", "pxX", "pt0", "pqb",
    "pqr", "pqB", "pqR", "pAB", "pAR", "pAb", "pAr", "pHX", "pD0", "pHx", "pA2", "1a",  "1q",
    "1A",  "1Q",  "pS6", "11",  "pV4", "43",  "pf7", "pe9", "pc5", "pia", "pcU", "pcE", "pcu",
    "pce", "qpo", "pq1", "qpO", "pt3", "pqa", "pqq", "pqA", "pqQ", "pAA", "pAQ", "pAa", "pAq",
    "pKE", "pD3", "pKe", "pA1", "1b",  "1r",  "1B",  "1R",  "8x",  "12",  "8X",  "40",  "Xx",
    "Q2",  "XX",  "T0",  "Qb",  "Qr",  "QB",  "QR",  "F4",  "IB",  "C6",  "Ib",  "CV",  "CF",
    "Cv",  "Cf",  "ph",  "px",  "pH",  "pX",  "s6",  "p8",  "v4",  "yB",  "aB",  "aR",  "ab",
    "ar",  "hX",  "d0",  "hx",  "a2",  "0AC", "0AS", "0Ac", "0As", "0HY", "0D1", "0Hy", "0A3",
    "0Pi", "0Py", "0PI", "0PY", "0S7", "0P9", "0V5", "0YC", "0f5", "0iC", "0c7", "0ic", "0cW",
    "0cG", "0cw", "0cg", "0xy", "0q3", "0xY", "0t1", "0qc", "0qs", "0qC", "0qS", "413", "48y",
    "441", "48Y", "41s", "41c", "41S", "41C", "601", "71o", "653", "71O", "60q", "60a", "60Q",
    "60A", "037", "009", "065", "09C", "00i", "00y", "00I", "00Y", "225", "28a", "277", "249",
    "21k", "22e", "21K", "22E", "S7",  "P9",  "V5",  "YC",  "Pi",  "Py",  "PI",  "PY",  "HY",
    "D1",  "Hy",  "A3",  "AC",  "AS",  "Ac",  "As",  "qc",  "qs",  "qC",  "qS",  "xy",  "q3",
    "xY",  "t1",  "cW",  "cG",  "cw",  "cg",  "f5",  "iC",  "c7",  "ic",  "phZ", "pd2", "phz",
    "9",   "I",   "Y",   "i",   "y",   "ps4", "qqt", "pv6", "pu8", "ppj", "ppz", "ppJ", "ppZ",
    "pCT", "pCD", "pCt", "pCd", "pF6", "pE8", "pC4", "pLB", "0i",  "0y",  "0I",  "0Y",  "37",
    "09",  "65",  "9C",  "408", "436", "49B", "464", "40x", "40h", "40X", "40H", "70t", "624",
    "648", "676", "61z", "61j", "61Z", "61J", "08x", "012", "08X", "040", "01b", "01r", "01B",
    "01R", "29z", "200", "29Z", "252", "25B", "20p", "25b", "20P", "0CV", "0CF", "0Cv", "0Cf",
    "0F4", "0IB", "0C6", "0Ib", "0Qb", "0Qr", "0QB", "0QR", "0Xx", "0Q2", "0XX", "0T0", "0hX",
    "0d0", "0hx", "0a2", "0aB", "0aR", "0ab", "0ar", "0s6", "0p8", "0v4", "0yB", "0ph", "0px",
    "0pH", "0pX", "49d", "430", "49D", "462", "46B", "40n", "46b", "40N", "68f", "622", "68F",
    "670", "62b", "61l", "62B", "61L", "10j", "014", "078", "046", "01d", "01t", "01D", "01T",
    "238", "206", "31H", "254", "20f", "20v", "20F", "20V", "0CP", "0Fb", "0Cp", "0FB", "0F2",
    "0ID", "0C0", "0Id", "0Qd", "0Qt", "0QD", "0QT", "1Pj", "0Q4", "0W8", "0T6", "0g8", "0d6",
    "0nB", "0a4", "0aD", "0aT", "0ad", "0at", "0s0", "0yd", "0v2", "0yD", "0pn", "0vB", "0pN",
    "0vb", "S1",  "Ye",  "V3",  "YE",  "Po",  "Sa",  "PO",  "SA",  "G9",  "D7",  "Ka",  "A5",
    "AE",  "AU",  "Ae",  "Au",  "qe",  "qu",  "qE",  "qU",  "t3b", "q5",  "w9",  "t7",  "cQ",
    "cA",  "cq",  "ca",  "f3",  "iE",  "c1",  "ie",  "pkB", "pd4", "pb8", "pa6", "O",   "paV",
    "o",   "pav", "ps2", "pyf", "pv0", "pyF", "ppl", "psb", "ppL", "psB", "pCR", "pCB", "pCr",
    "pCb", "pF0", "pIF", "pC2", "pIf", "0o",  "3a",  "0O",  "3A",  "31",  "9e",  "63",  "9E",
    "0AE", "0AU", "0Ae", "0Au", "0G9", "0D7", "0Ka", "0A5", "0Po", "0Sa", "0PO", "0SA", "0S1",
    "0Ye", "0V3", "0YE", "0f3", "0iE", "0c1", "0ie", "0cQ", "0cA", "0cq", "0ca", "1pk", "0q5",
    "0w9", "0t7", "0qe", "0qu", "0qE", "0qU", "415", "50k", "447", "479", "41u", "41e", "41U",
    "41E", "607", "639", "655", "71I", "60w", "60g", "60W", "60G", "031", "09e", "063", "09E",
    "00o", "03a", "00O", "03A", "223", "28g", "271", "28G", "21m", "22c", "21M", "22C", "pf1",
    "piG", "pc3", "pig", "pcS", "pcC", "pcs", "pcc", "pr9", "pq7", "qpI", "pt5", "pqg", "pqw",
    "pqG", "pqW", "pAG", "pAW", "pAg", "pAw", "pKC", "pD5", "pB9", "pA7", "1d",  "1t",  "1D",
    "1T",  "pS3", "14",  "78",  "46",  "p33", "Q4",  "W8",  "T6",  "Qd",  "Qt",  "QD",  "QT",
    "F2",  "ID",  "C0",  "Id",  "CP",  "Fb",  "Cp",  "FB",  "pn",  "vB",  "pN",  "vb",  "s0",
    "yd",  "v2",  "yD",  "aD",  "aT",  "ad",  "at",  "g8",  "d6",  "nB",  "a4",  "R9",  "Q7",
    "p62", "T5",  "Qg",  "Qw",  "QG",  "QW",  "F1",  "IG",  "C3",  "Ig",  "CS",  "CC",  "Cs",
    "Cc",  "pm",  "sc",  "pM",  "sC",  "s3",  "yg",  "v1",  "yG",  "aG",  "aW",  "ag",  "aw",
    "kC",  "d5",  "b9",  "a7",  "pf2", "piD", "pc0", "pid", "pcP", "pfb", "pcp", "pfB", "qpj",
    "pq4", "pw8", "pt6", "pqd", "pqt", "pqD", "pqT", "pAD", "pAT", "pAd", "pAt", "pG8", "pD6",
    "pNB", "pA4", "1g",  "1w",  "1G",  "1W",  "29",  "17",  "pV2", "45",  "416", "428", "444",
    "50H", "41v", "41f", "41V", "41F", "604", "71j", "656", "668", "60t", "60d", "60T", "60D",
    "032", "09f", "060", "09F", "00l", "03b", "00L", "03B", "220", "28d", "272", "28D", "21n",
    "27B", "21N", "27b", "0AF", "0AV", "0Af", "0Av", "0KB", "0D4", "0B8", "0A6", "0Pl", "0Sb",
    "0PL", "0SB", "0S2", "0Yf", "0V0", "0YF", "0f0", "0iF", "0c2", "0if", "0cR", "0cB", "0cr",
    "0cb", "0r8", "0q6", "1pH", "0t4", "0qf", "0qv", "0qF", "0qV", "pg9", "pd7", "pka", "pa5",
    "L",   "paU", "l",   "pau", "ps1", "pye", "pv3", "pyE", "ppo", "psa", "ppO", "psA", "pCQ",
    "pCA", "pCq", "pCa", "pF3", "pIE", "pC1", "pIe", "0l",  "3b",  "0L",  "3B",  "32",  "9f",
    "60",  "9F",  "S2",  "Yf",  "V0",  "YF",  "Pl",  "Sb",  "PL",  "SB",  "KB",  "D4",  "B8",
    "A6",  "AF",  "AV",  "Af",  "Av",  "qf",  "qv",  "qF",  "qV",  "r8",  "q6",  "t3A", "t4",
    "cR",  "cB",  "cr",  "cb",  "f0",  "iF",  "c2",  "if",  "0CS", "0CC", "0Cs", "0Cc", "0F1",
    "0IG", "0C3", "0Ig", "0Qg", "0Qw", "0QG", "0QW", "0R9", "0Q7", "1PI", "0T5", "0kC", "0d5",
    "0b9", "0a7", "0aG", "0aW", "0ag", "0aw", "0s3", "0yg", "0v1", "0yG", "0pm", "0sc", "0pM",
    "0sC", "49g", "433", "49G", "461", "43c", "40m", "43C", "40M", "68e", "621", "68E", "673",
    "62a", "61o", "62A", "61O", "029", "017", "10I", "045", "01g", "01w", "01G", "01W", "31k",
    "205", "269", "257", "20e", "20u", "20E", "20U", "Xe",  "R1",  "XE",  "W3",  "Ra",  "Qo",
    "RA",  "QO",  "E7",  "F9",  "Io",  "Ja",  "CK",  "Eg",  "Ck",  "EG",  "pu",  "pe",  "pU",
    "pE",  "p5",  "za",  "u7",  "v9",  "bA",  "aO",  "ba",  "ao",  "hE",  "g3",  "he",  "b1",
    "pe4", "pjB", "pil", "pc8", "pcH", "pcX", "pch", "pcx", "pxf", "pr2", "pxF", "pw0", "prb",
    "pql", "prB", "pqL", "pBB", "pAL", "pBb", "pAl", "pHF", "pG0", "pHf", "pB2", "2a",  "1o",
    "2A",  "1O",  "8e",  "21",  "8E",  "73",  "420", "48d", "472", "48D", "41n", "47B", "41N",
    "47b", "632", "69f", "660", "69F", "60l", "63b", "60L", "63B", "004", "11j", "056", "068",
    "00t", "00d", "00T", "00D", "216", "228", "244", "30H", "21v", "21f", "21V", "21F", "0Gb",
    "0AN", "0GB", "0An", "0HD", "0G2", "0Hd", "0B0", "0Pt", "0Pd", "0PT", "0PD", "0P4", "1Qj",
    "0U6", "0V8", "0e6", "0f8", "0in", "0oB", "0cJ", "0cZ", "0cj", "0cz", "0xd", "0r0", "0xD",
    "0w2", "0wB", "0qn", "0wb", "0qN", "phG", "pg1", "4",   "pb3", "T",   "D",   "t",   "d",
    "pp7", "ps9", "pu5", "pzC", "ppw", "ppg", "ppW", "ppG", "pCI", "pCY", "pCi", "pCy", "pE5",
    "pJC", "pIm", "pC9", "0t",  "0d",  "0T",  "0D",  "04",  "pR3", "56",  "68",  "P4",  "p23",
    "U6",  "V8",  "Pt",  "Pd",  "PT",  "PD",  "HD",  "G2",  "Hd",  "B0",  "Gb",  "AN",  "GB",
    "An",  "wB",  "qn",  "wb",  "qN",  "xd",  "r0",  "xD",  "w2",  "cJ",  "cZ",  "cj",  "cz",
    "e6",  "f8",  "in",  "oB",  "0CK", "0Eg", "0Ck", "0EG", "0E7", "0F9", "0Io", "0Ja", "0Ra",
    "0Qo", "0RA", "0QO", "0Xe", "0R1", "0XE", "0W3", "0hE", "0g3", "0he", "0b1", "0bA", "0aO",
    "0ba", "0ao", "0p5", "0za", "0u7", "0v9", "0pu", "0pe", "0pU", "0pE", "51k", "405", "469",
    "457", "40e", "40u", "40E", "40U", "629", "617", "70I", "645", "61g", "61w", "61G", "61W",
    "08e", "021", "08E", "073", "02a", "01o", "02A", "01O", "29g", "233", "29G", "261", "23c",
    "20m", "23C", "20M", "438", "406", "51H", "454", "40f", "40v", "40F", "40V", "70j", "614",
    "678", "646", "61d", "61t", "61D", "61T", "08f", "022", "08F", "070", "02b", "01l", "02B",
    "01L", "29d", "230", "29D", "262", "26B", "20n", "26b", "20N", "0CH", "0CX", "0Ch", "0Cx",
    "0E4", "0JB", "0Il", "0C8", "0Rb", "0Ql", "0RB", "0QL", "0Xf", "0R2", "0XF", "0W0", "0hF",
    "0g0", "0hf", "0b2", "0bB", "0aL", "0bb", "0al", "0p6", "0s8", "0u4", "0zB", "0pv", "0pf",
    "0pV", "0pF", "P7",  "S9",  "U5",  "ZC",  "Pw",  "Pg",  "PW",  "PG",  "HG",  "G1",  "Hg",
    "B3",  "BC",  "AM",  "Bc",  "Am",  "rc",  "qm",  "rC",  "qM",  "xg",  "r3",  "xG",  "w1",
    "cI",  "cY",  "ci",  "cy",  "e5",  "jC",  "im",  "c9",  "phD", "pg2", "7",   "pb0", "W",
    "G",   "w",   "g",   "pp4", "qqj", "pu6", "pv8", "ppt", "ppd", "ppT", "ppD", "pCJ", "pCZ",
    "pCj", "pCz", "pE6", "pF8", "pIn", "pOB", "0w",  "0g",  "0W",  "0G",  "07",  "39",  "55",
    "pW2", "0BC", "0AM", "0Bc", "0Am", "0HG", "0G1", "0Hg", "0B3", "0Pw", "0Pg", "0PW", "0PG",
    "0P7", "0S9", "0U5", "0ZC", "0e5", "0jC", "0im", "0c9", "0cI", "0cY", "0ci", "0cy", "0xg",
    "0r3", "0xG", "0w1", "0rc", "0qm", "0rC", "0qM", "423", "48g", "471", "48G", "41m", "42c",
    "41M", "42C", "631", "69e", "663", "69E", "60o", "63a", "60O", "63A", "007", "039", "055",
    "11I", "00w", "00g", "00W", "00G", "215", "30k", "247", "279", "21u", "21e", "21U", "21E",
    "pe7", "pf9", "pio", "pja", "pcK", "peg", "pck", "peG", "pxe", "pr1", "pxE", "pw3", "pra",
    "pqo", "prA", "pqO", "pBA", "pAO", "pBa", "pAo", "pHE", "pG3", "pHe", "pB1", "2b",  "1l",
    "2B",  "1L",  "8f",  "22",  "8F",  "70",  "Xf",  "R2",  "XF",  "W0",  "Rb",  "Ql",  "RB",
    "QL",  "E4",  "JB",  "Il",  "C8",  "CH",  "CX",  "Ch",  "Cx",  "pv",  "pf",  "pV",  "pF",
    "p6",  "s8",  "u4",  "zB",  "bB",  "aL",  "bb",  "al",  "hF",  "g0",  "hf",  "b2",  "pe1",
    "piY", "pii", "piy", "pcM", "pea", "pcm", "peA", "pq9", "pr7", "pxC", "pw5", "pqy", "pqi",
    "pqY", "pqI", "pAY", "pAI", "pAy", "pAi", "pHC", "pG5", "pA9", "pB7", "1z",  "1j",  "1Z",
    "1J",  "pP3", "24",  "48",  "76",  "p03", "R4",  "T8",  "W6",  "Qz",  "Qj",  "QZ",  "QJ",
    "E2",  "IZ",  "Ij",  "Iz",  "CN",  "Eb",  "Cn",  "EB",  "pp",  "uB",  "pP",  "ub",  "p0",
    "yz",  "u2",  "yZ",  "aZ",  "aJ",  "az",  "aj",  "d8",  "g6",  "mB",  "b4",  "0BE", "0AK",
    "0Be", "0Ak", "0D9", "0G7", "0Ha", "0B5", "0Pq", "0Pa", "0PQ", "0PA", "0P1", "0Ze", "0U3",
    "0ZE", "0e3", "0jE", "0ik", "0je", "0cO", "0ec", "0co", "0eC", "0xa", "0r5", "0t9", "0w7",
    "0re", "0qk", "0rE", "0qK", "425", "48a", "477", "449", "41k", "42e", "41K", "42E", "637",
    "609", "665", "69C", "60i", "60y", "60I", "60Y", "001", "11o", "053", "11O", "00q", "00a",
    "00Q", "00A", "213", "28y", "241", "28Y", "21s", "21c", "21S", "21C", "P1",  "Ze",  "U3",
    "ZE",  "Pq",  "Pa",  "PQ",  "PA",  "D9",  "G7",  "Ha",  "B5",  "BE",  "AK",  "Be",  "Ak",
    "re",  "qk",  "rE",  "qK",  "xa",  "r5",  "t9",  "w7",  "cO",  "ec",  "co",  "eC",  "e3",
    "jE",  "ik",  "je",  "phB", "pg4", "1",   "pb6", "Q",   "A",   "q",   "a",   "pp2", "pyx",
    "pu0", "pyX", "ppr", "ppb", "ppR", "ppB", "pCL", "qG0", "pCl", "pI8", "pE0", "pIX", "pIh",
    "pIx", "0q",  "0a",  "0Q",  "0A",  "01",  "pR6", "53",  "pW4", "49z", "400", "49Z", "452",
    "45B", "40p", "45b", "40P", "68x", "612", "68X", "640", "61b", "61r", "61B", "61R", "10t",
    "024", "048", "076", "01z", "01j", "01Z", "01J", "208", "236", "29B", "264", "20x", "20h",
    "20X", "20H", "0CN", "0Eb", "0Cn", "0EB", "0E2", "0IZ", "0Ij", "0Iz", "0Qz", "0Qj", "0QZ",
    "0QJ", "1Pt", "0R4", "0T8", "0W6", "0d8", "0g6", "0mB", "0b4", "0aZ", "0aJ", "0az", "0aj",
    "0p0", "0yz", "0u2", "0yZ", "0pp", "0uB", "0pP", "0ub", "0CM", "0Ea", "0Cm", "0EA", "0E1",
    "0IY", "0Ii", "0Iy", "0Qy", "0Qi", "0QY", "0QI", "0Q9", "0R7", "0XC", "0W5", "0hC", "0g5",
    "0a9", "0b7", "0aY", "0aI", "0ay", "0ai", "0p3", "0yy", "0u1", "0yY", "0ps", "0pc", "0pS",
    "0pC", "49y", "403", "49Y", "451", "40c", "40s", "40C", "40S", "70o", "611", "70O", "643",
    "61a", "61q", "61A", "61Q", "019", "027", "08C", "075", "01y", "01i", "01Y", "01I", "29a",
    "235", "259", "267", "23e", "20k", "23E", "20K", "pd9", "pg7", "2",   "pb5", "R",   "B",
    "r",   "b",   "pp1", "pze", "pu3", "pzE", "ppq", "ppa", "ppQ", "ppA", "pCO", "pEc", "pCo",
    "pEC", "pE3", "pJE", "pIk", "pJe", "0r",  "0b",  "0R",  "0B",  "02",  "9x",  "50",  "9X",
    "P2",  "Yx",  "U0",  "YX",  "Pr",  "Pb",  "PR",  "PB",  "HB",  "G4",  "A8",  "B6",  "AX",
    "AH",  "Ax",  "Ah",  "qx",  "qh",  "qX",  "qH",  "q8",  "r6",  "xB",  "w4",  "cL",  "v13",
    "cl",  "i8",  "e0",  "iX",  "ih",  "ix",  "426", "418", "474", "48B", "41h", "41x", "41H",
    "41X", "634", "71t", "666", "658", "60j", "60z", "60J", "60Z", "002", "09x", "050", "09X",
    "00r", "00b", "00R", "00B", "210", "28z", "242", "28Z", "21p", "24B", "21P", "24b", "0AX",
    "0AH", "0Ax", "0Ah", "0HB", "0G4", "0A8", "0B6", "0Pr", "0Pb", "0PR", "0PB", "0P2", "0Yx",
    "0U0", "0YX", "0e0", "0iX", "0ih", "0ix", "0cL", "1g0", "0cl", "0i8", "0q8", "0r6", "0xB",
    "0w4", "0qx", "0qh", "0qX", "0qH", "Q9",  "R7",  "XC",  "W5",  "Qy",  "Qi",  "QY",  "QI",
    "E1",  "IY",  "Ii",  "Iy",  "CM",  "Ea",  "Cm",  "EA",  "ps",  "pc",  "pS",  "pC",  "p3",
    "yy",  "u1",  "yY",  "aY",  "aI",  "ay",  "ai",  "hC",  "g5",  "a9",  "b7",  "pe2", "piZ",
    "pij", "piz", "pcN", "peb", "pcn", "peB", "qpt", "pr4", "pt8", "pw6", "pqz", "pqj", "pqZ",
    "pqJ", "pAZ", "pAJ", "pAz", "pAj", "pD8", "pG6", "pMB", "pB4", "1y",  "1i",  "1Y",  "1I",
    "19",  "27",  "8C",  "75",  "50j", "414", "478", "446", "41d", "41t", "41D", "41T", "638",
    "606", "71H", "654", "60f", "60v", "60F", "60V", "09d", "030", "09D", "062", "06B", "00n",
    "06b", "00N", "28f", "222", "28F", "270", "22b", "21l", "22B", "21L", "0AT", "0AD", "0At",
    "0Ad", "0D6", "0G8", "0A4", "0NB", "0VB", "0Pn", "0Vb", "0PN", "0Yd", "0S0", "0YD", "0V2",
    "0iD", "0f2", "0id", "0c0", "0fb", "0cP", "0fB", "0cp", "0q4", "1pj", "0t6", "0w8", "0qt",
    "0qd", "0qT", "0qD", "Q5",  "p32", "T7",  "W9",  "Qu",  "Qe",  "QU",  "QE",  "IE",  "F3",
    "Ie",  "C1",  "CA",  "CQ",  "Ca",  "Cq",  "sa",  "po",  "sA",  "pO",  "ye",  "s1",  "yE",
    "v3",  "aU",  "aE",  "au",  "ae",  "d7",  "g9",  "a5",  "ka",  "piF", "pf0", "pif", "pc2",
    "pcB", "pcR", "pcb", "pcr", "pq6", "pr8", "pt4", "qpH", "pqv", "pqf", "pqV", "pqF", "pAV",
    "pAF", "pAv", "pAf", "pD4", "pKB", "pA6", "pB8", "1u",  "1e",  "1U",  "1E",  "15",  "pS2",
    "47",  "79",  "0CA", "0CQ", "0Ca", "0Cq", "0IE", "0F3", "0Ie", "0C1", "0Qu", "0Qe", "0QU",
    "0QE", "0Q5", "1Pk", "0T7", "0W9", "0d7", "0g9", "0a5", "0ka", "0aU", "0aE", "0au", "0ae",
    "0ye", "0s1", "0yE", "0v3", "0sa", "0po", "0sA", "0pO", "431", "49e", "463", "49E", "40o",
    "43a", "40O", "43A", "623", "68g", "671", "68G", "61m", "62c", "61M", "62C", "015", "10k",
    "047", "079", "01u", "01e", "01U", "01E", "207", "239", "255", "31I", "20w", "20g", "20W",
    "20G", "pd5", "pkC", "pa7", "pb9", "paW", "N",   "paw", "n",   "pyg", "ps3", "pyG", "pv1",
    "psc", "ppm", "psC", "ppM", "pCC", "pCS", "pCc", "pCs", "pIG", "pF1", "pIg", "pC3", "6B",
    "0n",  "6b",  "0N",  "9d",  "30",  "9D",  "62",  "Yd",  "S0",  "YD",  "V2",  "VB",  "Pn",
    "Vb",  "PN",  "D6",  "G8",  "A4",  "NB",  "AT",  "AD",  "At",  "Ad",  "qt",  "qd",  "qT",
    "qD",  "q4",  "t3c", "t6",  "w8",  "fb",  "cP",  "fB",  "cp",  "iD",  "f2",  "id",  "c0",
    "Yg",  "S3",  "YG",  "V1",  "Sc",  "Pm",  "SC",  "PM",  "D5",  "KC",  "A7",  "B9",  "AW",
    "AG",  "Aw",  "Ag",  "qw",  "qg",  "qW",  "qG",  "q7",  "r9",  "t5",  "t6b", "cC",  "cS",
    "cc",  "cs",  "iG",  "f1",  "ig",  "c3",  "pd6", "pg8", "pa4", "pnB", "paT", "M",   "pat",
    "m",   "pyd", "ps0", "pyD", "pv2", "pvB", "ppn", "pvb", "ppN", "pFb", "pCP", "pFB", "pCp",
    "pID", "pF2", "pId", "pC0", "3c",  "0m",  "3C",  "0M",  "9g",  "33",  "9G",  "61",  "432",
    "49f", "460", "49F", "40l", "43b", "40L", "43B", "620", "68d", "672", "68D", "61n", "67B",
    "61N", "67b", "016", "028", "044", "10H", "01v", "01f", "01V", "01F", "204", "31j", "256",
    "268", "20t", "20d", "20T", "20D", "0CB", "0CR", "0Cb", "0Cr", "0IF", "0F0", "0If", "0C2",
    "0Qv", "0Qf", "0QV", "0QF", "0Q6", "0R8", "0T4", "1PH", "0d4", "0kB", "0a6", "0b8", "0aV",
    "0aF", "0av", "0af", "0yf", "0s2", "0yF", "0v0", "0sb", "0pl", "0sB", "0pL", "piE", "pf3",
    "pie", "pc1", "pcA", "pcQ", "pca", "pcq", "pq5", "qpk", "pt7", "pw9", "pqu", "pqe", "pqU",
    "pqE", "pAU", "pAE", "pAu", "pAe", "pD7", "pG9", "pA5", "pKa", "1v",  "1f",  "1V",  "1F",
    "16",  "28",  "44",  "pV3", "Q6",  "R8",  "T4",  "p63", "Qv",  "Qf",  "QV",  "QF",  "IF",
    "F0",  "If",  "C2",  "CB",  "CR",  "Cb",  "Cr",  "sb",  "pl",  "sB",  "pL",  "yf",  "s2",
    "yF",  "v0",  "aV",  "aF",  "av",  "af",  "d4",  "kB",  "a6",  "b8",  "0AW", "0AG", "0Aw",
    "0Ag", "0D5", "0KC", "0A7", "0B9", "0Sc", "0Pm", "0SC", "0PM", "0Yg", "0S3", "0YG", "0V1",
    "0iG", "0f1", "0ig", "0c3", "0cC", "0cS", "0cc", "0cs", "0q7", "0r9", "0t5", "1pI", "0qw",
    "0qg", "0qW", "0qG", "429", "417", "50I", "445", "41g", "41w", "41G", "41W", "71k", "605",
    "669", "657", "60e", "60u", "60E", "60U", "09g", "033", "09G", "061", "03c", "00m", "03C",
    "00M", "28e", "221", "28E", "273", "22a", "21o", "22A", "21O", "0AQ", "0AA", "0Aq", "0Aa",
    "0D3", "0KE", "0A1", "0Ke", "0Se", "0Pk", "0SE", "0PK", "0Ya", "0S5", "0U9", "0V7", "0e9",
    "0f7", "0ia", "0c5", "0cE", "0cU", "0ce", "0cu", "0q1", "1po", "0t3", "1pO", "0qq", "0qa",
    "0qQ", "0qA", "50o", "411", "50O", "443", "41a", "41q", "41A", "41Q", "69y", "603", "69Y",
    "651", "60c", "60s", "60C", "60S", "09a", "035", "059", "067", "03e", "00k", "03E", "00K",
    "219", "227", "28C", "275", "21y", "21i", "21Y", "21I", "piC", "pf5", "pic", "pc7", "pcG",
    "pcW", "pcg", "pcw", "pq3", "pxy", "pt1", "pxY", "pqs", "pqc", "pqS", "pqC", "pAS", "pAC",
    "pAs", "pAc", "pD1", "pHY", "pA3", "pHy", "1p",  "4B",  "1P",  "4b",  "10",  "8z",  "42",
    "8Z",  "Q0",  "Xz",  "T2",  "XZ",  "Qp",  "TB",  "QP",  "Tb",  "E8",  "F6",  "LB",  "C4",
    "CD",  "CT",  "Cd",  "Ct",  "pz",  "pj",  "pZ",  "pJ",  "t1c", "s4",  "u8",  "v6",  "aP",
    "db",  "ap",  "dB",  "d2",  "hZ",  "a0",  "hz",  "434", "51t", "466", "458", "40j", "40z",
    "40J", "40Z", "626", "618", "674", "68B", "61h", "61x", "61H", "61X", "010", "08z", "042",
    "08Z", "01p", "04B", "01P", "04b", "202", "29x", "250", "29X", "20r", "20b", "20R", "20B",
    "0CD", "0CT", "0Cd", "0Ct", "0E8", "0F6", "0LB", "0C4", "0Qp", "0TB", "0QP", "0Tb", "0Q0",
    "0Xz", "0T2", "0XZ", "0d2", "0hZ", "0a0", "0hz", "0aP", "0db", "0ap", "0dB", "1qt", "0s4",
    "0u8", "0v6", "0pz", "0pj", "0pZ", "0pJ", "Ya",  "S5",  "U9",  "V7",  "Se",  "Pk",  "SE",
    "PK",  "D3",  "KE",  "A1",  "Ke",  "AQ",  "AA",  "Aq",  "Aa",  "qq",  "qa",  "qQ",  "qA",
    "q1",  "t0x", "t3",  "t0X", "cE",  "cU",  "ce",  "cu",  "e9",  "f7",  "ia",  "c5",  "pd0",
    "phX", "pa2", "phx", "paR", "K",   "par", "k",   "pp8", "ps6", "pyB", "pv4", "ppx", "pph",
    "ppX", "ppH", "pCF", "pCV", "pCf", "pCv", "pIB", "pF4", "pIb", "pC6", "3e",  "0k",  "3E",
    "0K",  "9a",  "35",  "59",  "67",  "pd3", "pkE", "8",   "pke", "X",   "H",   "x",   "h",
    "pya", "ps5", "pu9", "pv7", "pse", "ppk", "psE", "ppK", "pCE", "pCU", "pCe", "pCu", "pE9",
    "pF7", "pIa", "pC5", "0x",  "0h",  "0X",  "0H",  "08",  "36",  "9B",  "64",  "P8",  "S6",
    "YB",  "V4",  "Px",  "Ph",  "PX",  "PH",  "D0",  "HX",  "A2",  "Hx",  "AR",  "AB",  "Ar",
    "Ab",  "qr",  "qb",  "qR",  "qB",  "q2",  "xx",  "t0",  "xX",  "cF",  "cV",  "cf",  "cv",
    "iB",  "f4",  "ib",  "c6",  "0CG", "0CW", "0Cg", "0Cw", "0IC", "0F5", "0Ic", "0C7", "0Qs",
    "0Qc", "0QS", "0QC", "0Q3", "0Xy", "0T1", "0XY", "0d1", "0hY", "0a3", "0hy", "0aS", "0aC",
    "0as", "0ac", "0p9", "0s7", "0yC", "0v5", "0py", "0pi", "0pY", "0pI", "437", "409", "465",
    "49C", "40i", "40y", "40I", "40Y", "625", "68a", "677", "649", "61k", "62e", "61K", "62E",
    "013", "08y", "041", "08Y", "01s", "01c", "01S", "01C", "201", "31o", "253", "31O", "20q",
    "20a", "20Q", "20A", "Q3",  "Xy",  "T1",  "XY",  "Qs",  "Qc",  "QS",  "QC",  "IC",  "F5",
    "Ic",  "C7",  "CG",  "CW",  "Cg",  "Cw",  "py",  "pi",  "pY",  "pI",  "p9",  "s7",  "yC",
    "v5",  "aS",  "aC",  "as",  "ac",  "d1",  "hY",  "a3",  "hy",  "pe8", "pf6", "plB", "pc4",
    "pcD", "pcT", "pcd", "pct", "pq0", "pxz", "pt2", "pxZ", "pqp", "ptB", "pqP", "ptb", "pAP",
    "pDb", "pAp", "pDB", "pD2", "pHZ", "pA0", "pHz", "1s",  "1c",  "1S",  "1C",  "13",  "8y",
    "41",  "8Y",  "48x", "412", "48X", "440", "41b", "41r", "41B", "41R", "69z", "600", "69Z",
    "652", "65B", "60p", "65b", "60P", "008", "036", "09B", "064", "00x", "00h", "00X", "00H",
    "30t", "224", "248", "276", "21z", "21j", "21Z", "21J", "0AR", "0AB", "0Ar", "0Ab", "0D0",
    "0HX", "0A2", "0Hx", "0Px", "0Ph", "0PX", "0PH", "0P8", "0S6", "0YB", "0V4", "0iB", "0f4",
    "0ib", "0c6", "0cF", "0cV", "0cf", "0cv", "0q2", "0xx", "0t0", "0xX", "0qr", "0qb", "0qR",
    "0qB",
};

#endif